@@ -210,11 +210,11 @@ module ActiveSupport
       # be specified as an option to the construction in which call all entries will be
       # affected. Or it can be supplied to the +fetch+ or +write+ method for just one entry.
       #
-      #   cache = ActiveSupport::Cache::MemoryStore.new(:expire_in => 5.minutes)
-      #   cache.write(key, value, :expire_in => 1.minute)  # Set a lower value for one entry
+      #   cache = ActiveSupport::Cache::MemoryStore.new(:expires_in => 5.minutes)
+      #   cache.write(key, value, :expires_in => 1.minute)  # Set a lower value for one entry
       #
       # Setting <tt>:race_condition_ttl</tt> is very useful in situations where a cache entry
-      # is used very frequently unver heavy load. If a cache expires and due to heavy load
+      # is used very frequently and is under heavy load. If a cache expires and due to heavy load
       # seven different processes will try to read data natively and then they all will try to
       # write to cache. To avoid that case the first process to find an expired cache entry will
       # bump the cache expiration time by the value set in <tt>:race_condition_ttl</tt>. Yes
@@ -230,7 +230,7 @@ module ActiveSupport
       # <tt>:race_condition_ttl</tt> does not play any role.
       #
       #   # Set all values to expire after one minute.
-      #   cache = ActiveSupport::Cache::MemoryCache.new(:expires_in => 1.minute)
+      #   cache = ActiveSupport::Cache::MemoryStore.new(:expires_in => 1.minute)
       #
       #   cache.write("foo", "original value")
       #   val_1 = nil
@@ -345,7 +345,7 @@ module ActiveSupport
           entry = read_entry(key, options)
           if entry
             if entry.expired?
-              delete_entry(key)
+              delete_entry(key, options)
             else
               results[name] = entry.value
             end
@@ -484,19 +484,20 @@ module ActiveSupport
         # object responds to +cache_key+. Otherwise, to_param method will be
         # called. If the key is a Hash, then keys will be sorted alphabetically.
         def expanded_key(key) # :nodoc:
-          if key.respond_to?(:cache_key)
-            key = key.cache_key.to_s
-          elsif key.is_a?(Array)
+          return key.cache_key.to_s if key.respond_to?(:cache_key)
+
+          case key
+          when Array
             if key.size > 1
-              key.collect{|element| expanded_key(element)}.to_param
+              key = key.collect{|element| expanded_key(element)}
             else
-              key.first.to_param
+              key = key.first
             end
-          elsif key.is_a?(Hash)
-            key = key.to_a.sort{|a,b| a.first.to_s <=> b.first.to_s}.collect{|k,v| "#{k}=#{v}"}.to_param
-          else
-            key = key.to_param
+          when Hash
+            key = key.sort_by { |k,_| k.to_s }.collect{|k,v| "#{k}=#{v}"}
           end
+
+          key.to_param
         end
 
         # Prefix a key with the namespace. Namespace and key will be delimited with a colon.
@@ -589,11 +590,7 @@ module ActiveSupport
       # Check if the entry is expired. The +expires_in+ parameter can override the
       # value set when the entry was created.
       def expired?
-        if @expires_in && @created_at + @expires_in <= Time.now.to_f
-          true
-        else
-          false
-        end
+        @expires_in && @created_at + @expires_in <= Time.now.to_f
       end
 
       # Set a new time when the entry will expire.
